@@ -8,8 +8,9 @@ pub(crate) mod burn_cash;
 pub(crate) mod print_cash;
 
 impl<'info> Validate<'info> for BrrrCommon<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(self.bank, self.collateral.bank);
+        assert_keys_eq!(self.bank.crate_mint, self.crate_mint);
         assert_keys_eq!(self.crate_token, self.crate_collateral_tokens.owner);
         assert_keys_eq!(self.crate_mint, self.crate_token.mint);
         assert_keys_eq!(self.crate_collateral_tokens.mint, self.collateral.mint);
